"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElementBuilder = void 0;
const chalk_1 = __importDefault(require("chalk"));
const logger_1 = require("./../libs/logger");
const events_manager_1 = require("./../managers/events-manager");
const element_shadow_1 = require("./element-shadow");
const root_scene_1 = require("./root-scene");
class ElementBuilder {
    scene;
    elem;
    constructor(scene) {
        this.scene = scene;
    }
    log(level) {
        if (this.elem && level)
            this.elem.log = level;
        return this;
    }
    logger(logger, reused = false) {
        if (this.elem) {
            let thatLogger = reused ? logger : undefined;
            Object.defineProperty(this.elem, 'logger', {
                get() {
                    return thatLogger || (thatLogger = logger?.clone(this.tag));
                }
            });
        }
        return this;
    }
    tag(name) {
        if (this.elem) {
            this.elem.tag = name;
        }
        return this;
    }
    parent(g) {
        if (this.elem) {
            Object.defineProperty(this.elem, 'parent', {
                value: g,
                writable: false
            });
        }
        return this;
    }
    element(ElementClazz, ...args) {
        (0, element_shadow_1.copyElementShadowPrototype)(ElementClazz.prototype);
        this.elem = new ElementClazz(...args);
        Object.defineProperties(this.elem, {
            scene: {
                value: this.scene,
                writable: false
            },
            rootScene: {
                value: this.scene instanceof root_scene_1.RootScene ? this.scene : this.scene.rootScene,
                writable: false
            }
        });
        const exec = this.elem.exec;
        this.elem.exec = async function (parentResult) {
            events_manager_1.GlobalEvent.emit('element/exec');
            let isAddIndent;
            try {
                this.parentState = parentResult;
                this.$$markElementNeedReplace();
                await this.evalPropsBeforeExec();
                this.logger.setLevel(this.$$getLoggerLevel());
                isAddIndent = this.logger.is(logger_1.LoggerLevel.INFO) && !!this.parent?.title;
                if (isAddIndent)
                    this.logger.addIndent();
                this.title && this.logger.info('%s', this.title);
                this.result = await exec.call(this, parentResult);
            }
            catch (err) {
                this.error = err;
                if (!this.ignoreError)
                    throw err;
                this.logger.debug(chalk_1.default.yellow(`⚠️ ${this.error?.message}`));
            }
            finally {
                if (isAddIndent)
                    this.logger.removeIndent();
            }
            await this.setVarsAfterExec();
            return this.result;
        };
        const dispose = this.elem.dispose || (() => { });
        this.elem.dispose = async function () {
            events_manager_1.GlobalEvent.emit('element/dispose');
            await dispose.call(this);
        };
        return this;
    }
    build() {
        if (!this.elem)
            throw new Error('');
        return this.elem;
    }
}
exports.ElementBuilder = ElementBuilder;
//# sourceMappingURL=element-builder.js.map