"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Group = void 0;
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const element_shadow_1 = require("../element-shadow");
class Group extends element_shadow_1.ElementShadow {
    $$ignoreEvalProps = ['runs'];
    runs = [];
    constructor(props) {
        super();
        if (Array.isArray(props)) {
            props = {
                runs: props
            };
        }
        Object.assign(this, props);
        this.runs = this.runs?.filter(e => e) || [];
    }
    async newElement(nameOrClass, ...args) {
        let elem;
        if (typeof nameOrClass === 'string') {
            const name = nameOrClass;
            const ElemClass = await this.rootScene.tagsManager.loadElementClass(name, this.scene);
            elem = this.scene.elementBuilder
                .element(ElemClass, ...args)
                .tag(name)
                .parent(this)
                .logger(this.logger)
                .build();
        }
        else {
            const name = nameOrClass.name || nameOrClass.constructor?.name;
            const ElemClass = nameOrClass;
            elem = this.scene.elementBuilder
                .element(ElemClass, ...args)
                .tag(name)
                .parent(this)
                .logger(this.logger)
                .build();
        }
        return elem;
    }
    async exec(parentState) {
        return await this.runEachOfElements(parentState);
    }
    async runEachOfElements(parentState) {
        const asyncJobs = [];
        const runs = new Array();
        for (const _e of this.runs) {
            const e = typeof _e === 'string' ? { echo: { content: _e } } : _e;
            const name = Object.keys(e)[0];
            let props = e[name];
            let baseProps = {};
            if (props && typeof props === 'object' && !Array.isArray(props)) {
                let { '<-': inheritKeys, '->': exposeKey, skip, ...eProps } = props;
                if (inheritKeys)
                    eProps = (0, lodash_merge_1.default)({}, this.$$extend(inheritKeys), eProps);
                if (exposeKey)
                    this.$$export(exposeKey, (0, lodash_clonedeep_1.default)(eProps));
                const { if: condition, id, ignoreError, log, vars, async, loop, ...customProps } = eProps;
                baseProps = {
                    id,
                    if: condition,
                    ignoreError,
                    log,
                    vars,
                    async,
                    loop
                };
                props = customProps;
                if (skip)
                    continue;
            }
            const loop = baseProps.loop;
            if (loop === undefined) {
                if (asyncJobs.length && !baseProps?.async) {
                    await Promise.all(asyncJobs);
                    asyncJobs.splice(0, asyncJobs.length);
                }
                const elem = await this.createAndExecuteElement(asyncJobs, name, parentState, baseProps, props);
                if (elem)
                    runs.push(elem);
            }
            else {
                let loopCondition = await this.scene.getVars(loop, this);
                if (loopCondition) {
                    if (Array.isArray(loopCondition)) {
                        for (let i = 0; i < loopCondition.length; i++) {
                            const newElem = await this.createAndExecuteElement(asyncJobs, name, parentState, baseProps, props, {
                                loopKey: i,
                                loopValue: loopCondition[i]
                            });
                            if (newElem)
                                runs.push(newElem);
                        }
                    }
                    else if (typeof loopCondition === 'object') {
                        for (const key in loopCondition) {
                            const newElem = await this.createAndExecuteElement(asyncJobs, name, parentState, baseProps, props, {
                                loopKey: key,
                                loopValue: loopCondition[key]
                            });
                            if (newElem)
                                runs.push(newElem);
                        }
                    }
                    else if (loopCondition === true) {
                        while (loopCondition) {
                            const newElem = await this.createAndExecuteElement(asyncJobs, name, parentState, baseProps, props, {
                                loopValue: loopCondition
                            });
                            if (newElem)
                                runs.push(newElem);
                            loopCondition = await this.scene.getVars(loop, this);
                        }
                    }
                }
            }
        }
        if (asyncJobs.length) {
            await Promise.all(asyncJobs);
        }
        return runs;
    }
    async createAndExecuteElement(asyncJobs, name, parentState, baseProps, props, loopObj) {
        if (baseProps.if !== undefined) {
            const isContinue = await this.scene.getVars(baseProps.if, { parent: this, parentState, ...loopObj });
            if (!isContinue)
                return undefined;
        }
        const elem = await this.newElement(name, props && (0, lodash_clonedeep_1.default)(props));
        if (baseProps.id)
            this.scene.localVars[baseProps.id] = elem;
        Object.assign(elem, baseProps);
        if (loopObj)
            Object.assign(elem, loopObj);
        const p = elem.exec(parentState && (0, lodash_clonedeep_1.default)(parentState)).finally(() => elem.dispose());
        if (!elem.async) {
            await p;
        }
        else {
            asyncJobs.push(p);
        }
        return elem;
    }
}
exports.Group = Group;
//# sourceMappingURL=group.js.map