"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputSuggest = void 0;
const input_abstract_1 = require("./input.abstract");
const SuggestFunction = {
    STARTSWITH_AND_ALLOW_NEW(inp, choices = []) {
        if (!inp)
            return choices;
        const existed = choices.filter(e => e.title.toLowerCase().startsWith(inp.toLowerCase()));
        const isExisted = existed.length === 1 && existed[0].title.toLowerCase() === inp.toLowerCase();
        if (isExisted)
            return existed;
        return [{ title: inp, value: inp, disabled: true }, ...existed];
    },
    STARTSWITH(inp, choices = []) {
        if (!inp)
            return choices;
        const existed = choices.filter(e => e.title.toLowerCase().startsWith(inp.toLowerCase()));
        return existed;
    },
    INCLUDE_AND_ALLOW_NEW(inp, choices = []) {
        if (!inp)
            return choices;
        const existed = choices.filter(e => e.title.toLowerCase().includes(inp.toLowerCase()));
        const isExisted = existed.length === 1 && existed[0].title.toLowerCase() === inp.toLowerCase();
        if (isExisted)
            return existed;
        return [{ title: inp, value: inp, disabled: true }, ...existed];
    },
    INCLUDE(inp, choices = []) {
        if (!inp)
            return choices;
        const existed = choices.filter(e => e.title.toLowerCase().includes(inp.toLowerCase()));
        return existed;
    }
};
class InputSuggest extends input_abstract_1.InputAbstract {
    type = 'autocomplete';
    choices = [];
    limit;
    style;
    suggestType;
    get suggest() {
        return (this.suggestType && SuggestFunction[this.suggestType]) || SuggestFunction.INCLUDE_AND_ALLOW_NEW;
    }
    constructor({ choices, limit, style, suggestType, ...props }) {
        super(props);
        Object.assign(this, { choices, limit, style, suggestType });
    }
    async exec() {
        this.choices.forEach((choice, i) => {
            if (this.default !== undefined && this.default === choice.value) {
                this.default = +i;
            }
        });
        return await super.exec();
    }
}
exports.InputSuggest = InputSuggest;
//# sourceMappingURL=input-suggest.js.map