"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const file_temp_1 = require("../../libs/file-temp");
const testing_1 = require("../../testing");
const tag_register_1 = require("./tag-register");
test('Register a tag from a file', async () => {
    const tmp = new file_temp_1.FileTemp();
    try {
        await tmp.create(`
    module.exports = {
      name: 'tag1',
      constructor(props) {
        Object.assign(this, props)
      },
      exec() {
        this.logger.debug(this.name)
      },
      dispose() { }
    }`);
        const tr = await testing_1.Testing.newElement(tag_register_1.TagRegister, {
            tag1: tmp.file
        });
        await tr.exec();
        await tr.dispose();
        const Clazz = await testing_1.Testing.rootScene.tagsManager.loadElementClass('tag1', testing_1.Testing.rootScene);
        expect(Clazz).toBeDefined();
        const tag1 = await testing_1.Testing.newElement(Clazz);
        expect(tag1.name).toBe('tag1');
    }
    finally {
        tmp.remove();
    }
});
test('Register a tag from an object', async () => {
    const tr = await testing_1.Testing.newElement(tag_register_1.TagRegister, {
        tag1: `{
        name: 'tag1',
        constructor(props) {
          Object.assign(this, props)
        },
        exec() {
          this.logger.debug(this.name)
        },
        dispose() { }
      }`
    });
    await tr.exec();
    await tr.dispose();
    const Clazz = await testing_1.Testing.rootScene.tagsManager.loadElementClass('tag1', testing_1.Testing.rootScene);
    expect(Clazz).toBeDefined();
    const tag1 = await testing_1.Testing.newElement(Clazz);
    expect(tag1.name).toBe('tag1');
});
test('Register a tag from a class', async () => {
    const tr = await testing_1.Testing.newElement(tag_register_1.TagRegister, {
        tag1: `class {
        constructor(props) {
          Object.assign(this, props)
        }
        exec() {
          this.logger.debug(this.name)
        }
        dispose() { }
      }`
    });
    await tr.exec();
    await tr.dispose();
    const Clazz = await testing_1.Testing.rootScene.tagsManager.loadElementClass('tag1', testing_1.Testing.rootScene);
    expect(Clazz).toBeDefined();
    const tag1 = await testing_1.Testing.newElement(Clazz);
    expect(tag1.name).toBe('tag1');
});
//# sourceMappingURL=tag-register.spec.js.map