"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Test = void 0;
const chalk_1 = __importDefault(require("chalk"));
const element_shadow_1 = require("../element-shadow");
const test_error_1 = require("./test-error");
class Test extends element_shadow_1.ElementShadow {
    $$ignoreEvalProps = ['script', 'defaultTestTitle'];
    label;
    check;
    script;
    defaultTestTitle;
    constructor(props) {
        super();
        if (typeof props === 'string') {
            props = {
                check: props
            };
        }
        else {
            props.label = props.title;
            props.title = undefined;
        }
        Object.assign(this, props);
        if (!this.label)
            this.defaultTestTitle = this.check || this.script;
    }
    failed(description = '') {
        this.error = new test_error_1.TestError(description);
        throw this.error;
    }
    async exec() {
        try {
            if (this.check !== undefined) {
                const rs = this.check;
                if (!rs)
                    this.failed();
            }
            if (this.script) {
                try {
                    await this.callFunctionScript(this.script);
                }
                catch (err) {
                    this.failed(err?.message);
                }
            }
            this.label && this.logger.info(this.label);
        }
        catch (err) {
            if (err !== this.error)
                throw err;
            this.logger.error('%s\t%s', this.label || this.defaultTestTitle, chalk_1.default.gray(this.error.message));
        }
        return !this.error;
    }
}
exports.Test = Test;
//# sourceMappingURL=test.js.map