"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const format_1 = require("./format");
test('kebabToCamelCase', () => {
    expect((0, format_1.kebabToCamelCase)('test-name')).toBe('testName');
    expect((0, format_1.kebabToCamelCase)('test-id-123')).toBe('testId123');
});
test('format number', () => {
    expect((0, format_1.formatNumber)(1000999)).toBe('1,000,999');
});
test('format duration (ms)', () => {
    expect((0, format_1.formatDuration)(0 + 13)).toBe('13ms');
});
test('format duration (seconds)', () => {
    expect((0, format_1.formatDuration)(1000 + 13)).toBe('1s 13ms');
});
test('format duration (minutes)', () => {
    expect((0, format_1.formatDuration)((15 * 60 * 1000) + (5 * 1000) + 13)).toBe('15m 5s 13ms');
});
test('format duration (hours)', () => {
    expect((0, format_1.formatDuration)((4 * 60 * 60 * 1000) + (15 * 60 * 1000) + (5 * 1000) + 13)).toBe('4h 15m 5s 13ms');
});
test.each([
    { title: 'boolean', input: true, output: true },
    { title: 'boolean', input: false, output: false },
    { title: 'string', input: 'test', output: 'test' },
    { title: 'object', input: { name: 'user 1', address: { city: 'hn' }, hobbies: ['running', 'travel'] }, output: { name: 'user 1', address: { city: 'hn' }, hobbies: ['running', 'travel'] } },
    { title: 'number', input: 1, output: 1 },
    { title: 'array', input: [1, 2, 4], output: [1, 2, 4] },
    { title: 'null', input: null, output: null },
    { title: 'undefined', input: undefined, output: undefined }
])('try to parse "$title" to "object"', ({ input, output }) => {
    expect((0, format_1.tryToParseObject)(input)).toEqual(output);
});
test.each([
    { title: 'Unicode string', input: 'unicode đoàn thuận  thành', output: 'unicode doan thuan thanh' },
    { title: 'Special characters', input: 'author (thanh)', output: 'author thanh' },
    { title: 'Multiple spaces', input: 'author  - (!@#thanh)', output: 'author - thanh' },
    { title: 'File with a extension', input: 'author  - (!@#thanh).mp3', output: 'author - thanh.mp3' }
])('format file name $title', ({ input, output }) => {
    expect((0, format_1.formatFileName)(input)).toEqual(output);
});
//# sourceMappingURL=format.spec.js.map