"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("../../testing");
const time_1 = require("../time");
const jobs_manager_1 = require("./jobs-manager");
class MyJob {
    name;
    time;
    constructor(name, time) {
        this.name = name;
        this.time = time;
    }
    async jobExecute() {
        testing_1.Testing.logger.info('Exec ' + this.name);
        await (0, time_1.sleep)(this.time);
    }
}
class MyFailedJob {
    name;
    time;
    constructor(name, time) {
        this.name = name;
        this.time = time;
    }
    async jobExecute() {
        testing_1.Testing.logger.info('Exec ' + this.name);
        await (0, time_1.sleep)(this.time);
        throw new Error(this.name + ' is failed');
    }
}
test('Test jobs run successfully', async () => {
    let countRunningJob = 0;
    let countDoneJob = 0;
    let countSuccessJob = 0;
    const jm = new jobs_manager_1.JobsManager(testing_1.Testing.logger, {
        concurrent: 2,
        jobHandler: {
            onJobSuccess() {
                countSuccessJob++;
            },
            onJobRun() {
                countRunningJob++;
            },
            onJobDone() {
                countDoneJob++;
                countRunningJob--;
            }
        }
    });
    await jm.add(new MyJob('job 1', 500));
    await jm.add(new MyJob('job 2', 1000));
    await jm.add(new MyJob('job 3', 2000));
    await jm.add(new MyJob('job 4', 2000));
    setTimeout(() => jm.stop(), 1000);
    await jm.start();
    expect(countRunningJob).toBe(0);
    expect(countDoneJob).toBe(3);
    expect(countSuccessJob).toBe(3);
});
test('Test jobs run failed', async () => {
    let countRunningJob = 0;
    let countDoneJob = 0;
    let countSuccessJob = 0;
    let failName = '';
    const jm = new jobs_manager_1.JobsManager(testing_1.Testing.logger, {
        concurrent: 2,
        jobHandler: {
            onJobFailure(_error, job) {
                failName = job.name;
            },
            onJobSuccess() {
                countSuccessJob++;
            },
            onJobRun() {
                countRunningJob++;
            },
            onJobDone() {
                countDoneJob++;
                countRunningJob--;
            }
        }
    });
    await jm.add(new MyJob('job 1', 500));
    await jm.add(new MyFailedJob('job 2', 1000));
    await jm.add(new MyJob('job 3', 2000));
    await jm.add(new MyJob('job 4', 2000));
    setTimeout(() => jm.stop(), 1000);
    await jm.start();
    expect(countRunningJob).toBe(0);
    expect(countDoneJob).toBe(3);
    expect(countSuccessJob).toBe(2);
    expect(failName).toBe('job 2');
});
test('Test jobs run failed then stop', async () => {
    const jm = new jobs_manager_1.JobsManager(testing_1.Testing.logger, {
        concurrent: 2,
        jobHandler: {
            onJobFailure() {
                throw new Error('Stop here');
            }
        }
    });
    await jm.add(new MyJob('job 1', 500));
    await jm.add(new MyFailedJob('job 2', 1000));
    await jm.add(new MyJob('job 3', 2000));
    await jm.add(new MyJob('job 4', 2000));
    setTimeout(() => jm.stop(), 1000);
    try {
        await jm.start();
    }
    catch (err) {
        expect(err).toBeDefined();
    }
});
//# sourceMappingURL=jobs-manager.spec.js.map