"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isGetEvalExp = exports.getVars = exports.setVars = void 0;
const async_function_1 = require("./../libs/async-function");
async function setVars(varObj, vl, ctx, others) {
    if (!varObj)
        return;
    const vars = others.vars;
    if (typeof varObj === 'string') {
        vars[varObj] = vl;
        return [varObj];
    }
    const keys = Object.keys(varObj);
    for (const k of keys) {
        vars[k] = await getVars(varObj[k], ctx, others);
    }
    return keys;
}
exports.setVars = setVars;
async function getVars(exp, ctx, others) {
    if (exp) {
        const evalExp = isGetEvalExp(exp);
        if (evalExp === String) {
            let str = `\`${exp}\``;
            if (str[1] === '$' && str[str.length - 2] === '}') {
                str = str.replace(/^`\$\{([^}]+)\}`$/, '$1');
            }
            let vl = await (0, async_function_1.callFunctionScript)(`return ${str}`, ctx, others);
            if (typeof vl === 'string' && vl.includes('${')) {
                vl = await getVars(vl, ctx, others);
            }
            return vl;
        }
        else if (evalExp === Object) {
            const obj = await evalObject(exp, ctx, others);
            return obj;
        }
    }
    return exp;
}
exports.getVars = getVars;
function isGetEvalExp(vl) {
    if (!vl)
        return null;
    if (typeof vl === 'string') {
        if (vl.includes('${'))
            return String;
    }
    else if (typeof vl === 'object') {
        const typeName = vl.constructor?.toString();
        if (typeName?.startsWith('function Object() ') || typeName?.startsWith('function Array() ')) {
            if (isGetEvalExp(JSON.stringify(vl)))
                return Object;
        }
    }
    return null;
}
exports.isGetEvalExp = isGetEvalExp;
async function evalObject(obj, ctx, others) {
    if (Array.isArray(obj)) {
        const vl = await Promise.all(obj.map(async (o) => await getVars(o, ctx, others)));
        return vl;
    }
    for (const k of Object.keys(obj)) {
        obj[k] = await getVars(obj[k], ctx, others);
    }
    return obj;
}
//# sourceMappingURL=variable.js.map